@@ -6,7 +6,7 @@ import jinja2
 from boltons import fileutils
 
 from .. import answers, questions, template
-from ..environment import StrictNativeEnvironment
+from ..environment import StrictEnvironment, StrictNativeEnvironment
 
 
 def clone_tree(args, data, ctx):
@@ -14,7 +14,8 @@ def clone_tree(args, data, ctx):
     #
     # Get user options
     jinja_vars = data.get("jinja2", {})
-    env = StrictNativeEnvironment(context=data.get("extensions"), path=args["template_dir"], **jinja_vars)
+    nenv = StrictNativeEnvironment(context=data.get("extensions"), path=args["template_dir"], **jinja_vars)
+    env = StrictEnvironment(context=data.get("extensions"), path=args["template_dir"], **jinja_vars)
 
     # Get the template source directory (from command line)
     # It's the folder containing another folder named "template"
@@ -30,7 +31,7 @@ def clone_tree(args, data, ctx):
     for src in fileutils.iter_find_files(source_path, "*", include_dirs=True):
         dst = os.path.relpath(src, source_path)
         try:
-            dst = env.from_string(dst).render(**ctx)
+            dst = nenv.from_string(dst).render(**ctx)
         except jinja2.exceptions.UndefinedError as err:
             sys.exit(f'error: templating error during "{src}" file: {err}')
         dst = os.path.join(output, dst)
