@@ -1,4 +1,4 @@
-def var2bool(value):
+def string_as_bool(value):
     if isinstance(value, bool):
         return value
     if isinstance(value, int):
